NumaNode

Struct NumaNode 

pub struct NumaNode(/* private fields */);
Non Uniform Memory Access (NUMA) node identifier.

Implementations

Source

impl NumaNode

pub fn new(node: i32) -> Result<Self>

Create a new NUMA node identifier (non-negative integer).

Returns EINVAL if a negative id or an id exceeding [bindings::MAX_NUMNODES] is specified.

pub fn id(&self) -> i32

Returns the raw NUMA node identifier as an i32.

Source

impl NumaNode

Specify necessary constant to pass the information to Allocator that the caller doesn’t care about the NUMA node to allocate memory from.

pub const NO_NODE: NumaNode

No node preference.